==> rosegarden-trinity_3.5.13.2.orig.tar.xz: rosegarden-trinity-3.5.13.2/src/gui/studio/MixerWindow.cpp <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "MixerWindow.h"

#include "misc/Debug.h"
#include "base/MidiProgram.h"
#include "base/Studio.h"
#include "document/RosegardenGUIDoc.h"
#include <kmainwindow.h>
#include <tqaccel.h>
#include <tqwidget.h>


namespace Rosegarden
{

MixerWindow::MixerWindow(TQWidget *parent,
                         RosegardenGUIDoc *document) :
        KMainWindow(parent, "mixerwindow"),
        m_document(document),
        m_studio(&document->getStudio()),
        m_currentId(0)
{
    m_accelerators = new TQAccel(this);
}

void
MixerWindow::closeEvent(TQCloseEvent *e)
{
    RG_DEBUG << "MixerWindow::closeEvent()\n";
    emit closing();
    KMainWindow::closeEvent(e);
}

void
MixerWindow::windowActivationChange(bool)
{
    if (isActiveWindow()) {
        emit windowActivated();
        sendControllerRefresh();
    }
}

void
MixerWindow::slotClose()
{
    RG_DEBUG << "MixerWindow::slotClose()\n";
    close();
}

}
#include "MixerWindow.moc"

==> rosegarden-trinity-14.0.8.tar.xz: rosegarden-trinity-14.0.8/src/gui/studio/MixerWindow.cpp <==
/* -*- c-basic-offset: 4 indent-tabs-mode: nil -*- vi:set ts=8 sts=4 sw=4: */

/*
    Rosegarden
    A MIDI and audio sequencer and musical notation editor.
 
    This program is Copyright 2000-2008
        Guillaume Laurent   <glaurent@telegraph-road.org>,
        Chris Cannam        <cannam@all-day-breakfast.com>,
        Richard Bown        <richard.bown@ferventsoftware.com>
 
    The moral rights of Guillaume Laurent, Chris Cannam, and Richard
    Bown to claim authorship of this work have been asserted.
 
    Other copyrights also apply to some parts of this work.  Please
    see the AUTHORS file and individual file headers for details.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.  See the file
    COPYING included with this distribution for more information.
*/


#include "MixerWindow.h"

#include "misc/Debug.h"
#include "base/MidiProgram.h"
#include "base/Studio.h"
#include "document/RosegardenGUIDoc.h"
#include <tdemainwindow.h>
#include <tqaccel.h>
#include <tqwidget.h>


namespace Rosegarden
{

MixerWindow::MixerWindow(TQWidget *parent,
                         RosegardenGUIDoc *document) :
        TDEMainWindow(parent, "mixerwindow"),
        m_document(document),
        m_studio(&document->getStudio()),
        m_currentId(0)
{
    m_accelerators = new TQAccel(this);
}

void
MixerWindow::closeEvent(TQCloseEvent *e)
{
    RG_DEBUG << "MixerWindow::closeEvent()\n";
    emit closing();
    TDEMainWindow::closeEvent(e);
}

void
MixerWindow::windowActivationChange(bool)
{
    if (isActiveWindow()) {
        emit windowActivated();
        sendControllerRefresh();
    }
}

void
MixerWindow::slotClose()
{
    RG_DEBUG << "MixerWindow::slotClose()\n";
    close();
}

}
#include "MixerWindow.moc"
